Csr location class shows location and satellite information, which supports H13467 + ST F103RB/NXP LCP1549 boards now.

Dependents:   CsrLocationDemo CsrLocationDemo

Fork of CsrLocation by jie zhao

Revision:
19:27aa296d2ea1
Parent:
18:5d72465991f5
--- a/CsrLocation.h	Tue Nov 18 09:03:17 2014 +0000
+++ b/CsrLocation.h	Wed Nov 19 01:34:48 2014 +0000
@@ -189,14 +189,14 @@
 typedef struct GpsTime {
     /** Week part of GPS time */
     uint16_t gps_week;
     /** Time of second part of GPS time */
     uint32_t tow;
 } tGpsTime;
 
 /** Structure to hold Position Response Message Information. */
 typedef struct LocPosResp {
-    tGpsTime gpsTime;
-    uint64_t utcTime;
+    tGpsTime gpsTime; /** gps time */
+    uint64_t utcTime; /** UTC time in millisecond */
     /** Latitude */
     double lat;
     /** Longitude */
@@ -189,14 +189,14 @@
     /** Week part of GPS time */
     uint16_t gps_week;
-    /** Time of second part of GPS time */
+    /** Time of second part of GPS time in millisecond */
     uint32_t tow;
 } tGpsTime;